@@ -6,7 +6,7 @@ from rich.console import Console
 from i8_terminal.commands.financials import financials
 from i8_terminal.common.cli import pass_command
 from i8_terminal.common.financials import available_fin_df2tree
-from i8_terminal.common.utils import validate_ticker
+from i8_terminal.common.stock_info import validate_ticker
 from i8_terminal.types.ticker_param_type import TickerParamType
 
 
@@ -19,6 +19,14 @@ def get_available_financials_df(ticker: str) -> DataFrame:
 @click.option("--ticker", "-k", type=TickerParamType(), required=True, callback=validate_ticker, help="Company ticker.")
 @pass_command
 def coverage(ticker: str) -> None:
+    """
+    Shows available financial statements of the given company.
+
+    Examples:
+
+    `i8 financials coverage --ticker AAPL`
+
+    """
     console = Console()
     with console.status("Fetching data...", spinner="material"):
         available_fin_df = get_available_financials_df(ticker)
