@@ -6,6 +6,7 @@ from rich.console import Console
 
 from i8_terminal.commands.watchlist import watchlist
 from i8_terminal.common.cli import pass_command
+from i8_terminal.common.stock_info import validate_tickers
 from i8_terminal.config import USER_SETTINGS
 from i8_terminal.types.ticker_param_type import TickerParamType
 
@@ -22,9 +23,24 @@ def create_watchlist(name: str, tickers: List[str]) -> None:
     "-n",
     help="Name of the watchlist you want to create.",
 )
-@click.option("--tickers", "-k", type=TickerParamType(), required=True, help="Comma-separated list of tickers.")
+@click.option(
+    "--tickers",
+    "-k",
+    type=TickerParamType(),
+    required=True,
+    callback=validate_tickers,
+    help="Comma-separated list of tickers.",
+)
 @pass_command
 def create(name: str, tickers: str) -> None:
+    """
+    Creates new watchlist with given name and tickers.
+
+    Examples:
+
+    `i8 watchlist create --name MyWatchlist --tickers AAPL,MSFT`
+
+    """
     console = Console()
     tickers_list = tickers.replace(" ", "").upper().split(",")
     with console.status("Creating Watchlist...", spinner="material"):
